@@ -90,6 +90,7 @@ class SubmitCommand:
       self.separators           = []
       self.nCores               = None
       self.ppn                  = None
+      self.nStripes             = None
       self.wallTime             = None
       self.environmentVariables = {}
       self.runName              = ""
@@ -651,8 +652,10 @@ class SubmitCommand:
 
    def __loadVenues(self):
       self.resetVenues()
-      if 'venues' in self.savedCommand:
+      if   'venues' in self.savedCommand:
          self.setVenues(self.savedCommand['venues'])
+      elif 'venue' in self.savedCommand:
+         self.setVenues(self.savedCommand['venue'])
 
 
    def setInputFiles(self,
@@ -979,6 +982,49 @@ class SubmitCommand:
          self.setPPN(self.savedCommand['ppn'])
 
 
+   def setNstripes(self,
+                   nStripes):
+      """
+      Set number of parallel stripes to be used in a local
+      parametric sweep run.
+      """
+      setError = False
+      if isinstance(nStripes,int):
+         self.nStripes = nStripes
+      else:
+         self.logger.log(logging.ERROR,getLogMessage("nStripes must be an integer"))
+         setError = True
+
+      return(setError)
+
+
+   def resetNstripes(self):
+      """
+      Set number of parallel stripes to be used in a local
+      parametric sweep run to the default value.
+      """
+      resetError = False
+      self.nStripes = None
+
+      return(resetError)
+
+
+   def __addNstripesArgs(self):
+      if self.nStripes:
+         self.args += ['--stripes',str(self.nStripes)]
+
+
+   def __saveNstripes(self):
+      if self.nStripes:
+         self.savedCommand['nStripes'] = self.nStripes
+
+
+   def __loadNstripes(self):
+      self.resetNstripes()
+      if 'nStripes' in self.savedCommand:
+         self.setNstripes(self.savedCommand['nStripes'])
+
+
    def setWallTime(self,
                    wallTime):
       """
@@ -1846,6 +1892,7 @@ class SubmitCommand:
                self.__addRunNameArgs()
                if self.local:
                   self.__addLocalArg()
+                  self.__addNstripesArgs()
                else:
                   self.__addVenuesArgs()
                   self.__addNcoresArgs()
@@ -1886,6 +1933,7 @@ class SubmitCommand:
       self.__resetDataFile()
       self.__resetNcores()
       self.__resetPPN()
+      self.__resetNstripes()
       self.__resetWallTime()
       self.__resetEnvironmentVariables()
       self.__resetRunName()
@@ -1929,6 +1977,7 @@ class SubmitCommand:
       self.__saveDataFile()
       self.__saveNcores()
       self.__savePPN()
+      self.__saveNstripes()
       self.__saveWallTime()
       self.__saveEnvironmentVariables()
       self.__saveRunName()
@@ -2000,7 +2049,6 @@ class SubmitCommand:
          self.__loadQueryJobs()
          self.__loadKillJobs()
          self.__loadVenueStatus()
-         self.__loadVenue()
          self.__loadVenues()
          self.__loadInputFiles()
          self.__loadDefaultSeparator()
@@ -2008,6 +2056,7 @@ class SubmitCommand:
          self.__loadDataFile()
          self.__loadNcores()
          self.__loadPPN()
+         self.__loadNstripes()
          self.__loadWallTime()
          self.__loadEnvironmentVariables()
          self.__loadRunName()
@@ -2142,7 +2191,7 @@ class SubmitCommand:
                      self.logger.setLevel(logging.DEBUG)
                   if contactServer:
                      self.submitClient.getUserAttributes()
-                     if self.submitClient.connectToServer():
+                     if self.submitClient.connectToServer('execute'):
                         result = self.submitClient.run()
                      else:
                         exitCode = 1
@@ -2159,7 +2208,8 @@ class SubmitCommand:
 
       if not result:
          result = {}
-         result['exitCode'] = exitCode
+         result['exitCode']           = exitCode
+         result['serverDisconnected'] = False
 
       return(result)
 
